Skip to contents

NOTE: Currently only an internal function and not tested.

Usage

load_rdss_recursive(
  x_name = ".*",
  class,
  sub = sbf_get_sub(),
  main = sbf_get_main(),
  include_root = TRUE,
  tag = ".*",
  meta = FALSE,
  drop = NULL,
  fun = NULL,
  ext = "rds"
)

Arguments

x_name

A string of the name.

class

Class of object to import, which determines the sub to import from.

sub

A string specifying the path to the sub folder (by default the current sub folder).

main

A string specifying the path to the main folder (by default the current main folder)

include_root

A flag indicating whether to include objects in the top sub folder.

tag

A string of the regular expression that the tag must match to be included.

meta

A flag specifying whether to include the report, caption and any other metadata as columns.

drop

A character vector specifying the names of sub folders and files to drop or NULL (the default).

fun

function to apply to the object after import (NULL by default)

ext

Extension of the files (".rds" by default)

Value

a tibble of the loaded objects

Details

Recursively loads all RDS files with names matching the regular expression x_name as the first (list) column (named object) in a data frame. Subsequent character vector columns specify the object names (named name) and sub folders (named sub1, sub2 etc).