Load RDS files as List Column in Data Frame
load_rdss_recursive.RdNOTE: Currently only an internal function and not tested.
Usage
load_rdss_recursive(
x_name = ".*",
class,
sub = sbf_get_sub(),
main = sbf_get_main(),
include_root = TRUE,
tag = ".*",
meta = FALSE,
drop = NULL,
fun = NULL,
ext = "rds"
)Arguments
- x_name
A string of the name.
- class
Class of object to import, which determines the sub to import from.
- sub
A string specifying the path to the sub folder (by default the current sub folder).
- main
A string specifying the path to the main folder (by default the current main folder)
- include_root
A flag indicating whether to include objects in the top sub folder.
- tag
A string of the regular expression that the tag must match to be included.
- meta
A flag specifying whether to include the report, caption and any other metadata as columns.
- drop
A character vector specifying the names of sub folders and files to drop or
NULL(the default).- fun
function to apply to the object after import (
NULLby default)- ext
Extension of the files (
".rds"by default)
Details
Recursively loads all RDS files with names matching the regular expression
x_name as the first (list) column (named object) in a data frame.
Subsequent character vector columns specify the object names (named name)
and sub folders (named sub1, sub2 etc).
See also
Other load functions:
sbf_load_block(),
sbf_load_blocks(),
sbf_load_blocks_recursive(),
sbf_load_data(),
sbf_load_data_from_db(),
sbf_load_data_from_pg(),
sbf_load_datas(),
sbf_load_datas_from_db(),
sbf_load_datas_from_pg(),
sbf_load_datas_recursive(),
sbf_load_db_metatable(),
sbf_load_number(),
sbf_load_numbers(),
sbf_load_numbers_recursive(),
sbf_load_object(),
sbf_load_objects(),
sbf_load_objects_recursive(),
sbf_load_plot(),
sbf_load_plot_data(),
sbf_load_plots_data(),
sbf_load_plots_data_recursive(),
sbf_load_plots_recursive(),
sbf_load_spatial(),
sbf_load_spatials(),
sbf_load_string(),
sbf_load_strings(),
sbf_load_strings_recursive(),
sbf_load_table(),
sbf_load_tables(),
sbf_load_tables_recursive(),
sbf_load_windows_recursive(),
sbf_subs_block_recursive(),
sbf_subs_data_recursive(),
sbf_subs_number_recursive(),
sbf_subs_object_recursive(),
sbf_subs_plot_recursive(),
sbf_subs_string_recursive(),
sbf_subs_table_recursive(),
sbf_subs_window_recursive()